@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.aws_autoscaling._jsii
 import aws_cdk.aws_ec2._jsii
@@ -19,7 +19,7 @@ import aws_cdk.custom_resources._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@aws-cdk/aws-eks", "1.63.0", __name__[0:-6], "aws-eks@1.63.0.jsii.tgz"
+    "@aws-cdk/aws-eks", "1.64.0", __name__[0:-6], "aws-eks@1.64.0.jsii.tgz"
 )
 
 __all__ = [
